@@ -1,7 +1,7 @@
 package App::CSVUtils;
 
-our $DATE = '2019-04-15'; # DATE
-our $VERSION = '0.015'; # VERSION
+our $DATE = '2019-04-23'; # DATE
+our $VERSION = '0.016'; # VERSION
 
 use 5.010001;
 use strict;
@@ -334,6 +334,8 @@ sub csvutil {
         $csv->getline($fh);
     };
 
+    my $rows = [];
+
     while (my $row = $code_getline->()) {
         $i++;
         if ($i == 1) {
@@ -592,6 +594,17 @@ sub csvutil {
             if ($i == $args{_row_number}) {
                 $selected_row = $row;
             }
+        } elsif ($action eq 'dump') {
+            my $rowhash;
+            if ($args{hash}) {
+                $rowhash = {};
+                for (0..$#{$fields}) {
+                    $rowhash->{ $fields->[$_] } = $row->[$_];
+                }
+                push @$rows, $rowhash unless $i == 1;
+            } else {
+                push @$rows, $row;
+            }
         } else {
             return [400, "Unknown action '$action'"];
         }
@@ -618,8 +631,13 @@ sub csvutil {
                              $args{_with_data_rows} ? $i+1 : 2,
                              $has_header);
     }
+
+    if ($action eq 'dump') {
+        return [200, "OK", $rows];
+    }
+
     [200, "OK", $res, {"cmdline.skip_format"=>1}];
-}
+} # csvutil
 
 $SPEC{csv_add_field} = {
     v => 1.1,
@@ -1103,6 +1121,20 @@ sub csv_select_fields {
             _fields => $args{fields}, _field_pat => $args{field_pat});
 }
 
+$SPEC{csv_dump} = {
+    v => 1.1,
+    summary => 'Dump CSV as data structure (array of array/hash)',
+    args => {
+        %args_common,
+        %arg_filename_0,
+        %arg_hash,
+    },
+};
+sub csv_dump {
+    my %args = @_;
+    csvutil(%args, action=>'dump');
+}
+
 1;
 # ABSTRACT: CLI utilities related to CSV
 
@@ -1118,7 +1150,7 @@ App::CSVUtils - CLI utilities related to CSV
 
 =head1 VERSION
 
-This document describes version 0.015 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2019-04-15.
+This document describes version 0.016 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2019-04-23.
 
 =head1 DESCRIPTION
 
@@ -1136,6 +1168,8 @@ This distribution contains the following CLI utilities:
 
 =item * L<csv-delete-field>
 
+=item * L<csv-dump>
+
 =item * L<csv-each-row>
 
 =item * L<csv-grep>
@@ -1156,6 +1190,8 @@ This distribution contains the following CLI utilities:
 
 =item * L<csv-sum>
 
+=item * L<dump-csv>
+
 =back
 
 =head1 FUNCTIONS
@@ -1433,6 +1469,50 @@ Return value:  (any)
 
 
 
+=head2 csv_dump
+
+Usage:
+
+ csv_dump(%args) -> [status, msg, payload, meta]
+
+Dump CSV as data structure (array of array/hash).
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<filename>* => I<filename>
+
+Input CSV file.
+
+=item * B<hash> => I<bool>
+
+Provide row in $_ as hashref instead of arrayref.
+
+=item * B<header> => I<bool> (default: 1)
+
+Whether CSV has a header row.
+
+When you declare that CSV does not have header row (C<--no-header>), the fields
+will be named C<field1>, C<field2>, and so on.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 csv_each_row
 
 Usage:
